/**
 * @file
 * Gulpfile for fortytwo.
 */

 var gulp = require('gulp'),
   $ = require('gulp-load-plugins')(),
   del = require('del'),
   runSequence = require('run-sequence');

/**
 * @task sass
 * Do sass and reload tasks in sequence.
 */
gulp.task('sass', function () {
  runSequence('sass-compile');
});

gulp.task('sass-compile', function () {
  return gulp.src('static/sass/**/*.s+(a|c)ss') // Gets all files ending
      .pipe($.sass())
      .on('error', function (err) {
        console.log(err);
        this.emit('end');
      })
      .pipe($.autoprefixer({
        browsers: ['ie 8-9', 'last 2 versions']
      }))
      .pipe(gulp.dest('static/css'));
});

/**
 * @task js
 * Do javascript stuff.
 */
gulp.task('js', function () {
  return gulp.src(['static/js/**/*.js', '!static/js/lib/*.js'])
    .pipe($.jscs({fix: true}))
    .pipe($.jscs.reporter())
    .pipe($.uglify());
});

/**
 * @task clean
 * Clean the dist folder.
 */
gulp.task('clean', function () {
  return del(['static/css/*']);
});

/**
 * @task watch
 * Watch files and do stuff.
 */
gulp.task('watch', ['clean', 'sass', 'js'], function () {
  gulp.watch('static/sass/**/*.+(scss|sass)', ['sass']);
  gulp.watch('static/js/**/*.js', ['js']);
});

/**
 * @task default
 * Watch files and do stuff.
 */
gulp.task('default', ['watch']);
